@@ -1,18 +1,19 @@
 
-from openpyxl.styles import protection
 from source.excel import Excel
 from case.common import ExcelMaker,valid_programs
 import argparse
 from functools import reduce
 from termcolor import colored
+import json
 
 def main():
     parser=argparse.ArgumentParser(description="For munipulate excel and get data source...")
     
+    parser.add_argument("-e", "--excel", help="Input excel name")
     parser.add_argument("-a", "--add", help="add up excels(can be more than 2), and output to another excel",nargs="+")
     parser.add_argument("-s", "--sub", help="sub excels(can be more than 2), and output to another excel",nargs="+")
-    parser.add_argument("-c", "--copy", help="copy later excel's common contents to first excel (only two excels), and output to another excel",nargs="+")
-    parser.add_argument("-t", "--to", help="Output excel file name")
+    parser.add_argument("-c", "--copy", help="copy later excels' common contents to first excel(can be more than 2), and output to another excel",nargs="+")
+    parser.add_argument("-t", "--to", help="Output file name")
     parser.add_argument("-po", "--protection_off", help="Protection off. default is On",action='store_true')
     parser.add_argument("-j", "--json", help="need json output",action='store_true')
     parser.add_argument("-d", "--dict", help="need dict output",action='store_true')
@@ -54,12 +55,11 @@ def main():
             print(colored(f'{str(e)}','red'))
     
     if args.copy and args.to:
-        if len(args.copy)!=2:
-            raise ValueError("Must two excel files after -c ")
+        if len(args.copy)<2:
+            raise ValueError("Must  more than two excel files after -c ")
         try:
-            excel_objs=[Excel[x] for x in args.copy]
-            print(excel_objs)
-            e=excel_objs[0].copy(excel_objs[1])
+            excel_objs=list(map(lambda x:Excel(x), args.copy))
+            e=reduce(lambda a,b:a.copy(b), excel_objs)
             e.makeExcel(args.to,protection=protection)
             print(colored(f'{args.to} saved',"green"))
             if args.json:
@@ -77,6 +77,12 @@ def main():
             return
         excel_file=ExcelMaker(args.program)
         excel_file.makeExcelBasedOnModel(args.to)
+    
+    if args.excel and args.to and args.json:
+        excel=Excel(args.excel)
+        with open(args.to,'w') as fp:
+            json.dump(excel.dict,fp,indent=3,default=str)
+        print(colored(f"{args.to} is saved","green"))
         
 if __name__=="__main__":
     main()
